@@ -12,39 +12,39 @@
 
 // #include the widget headers so that we can call the get_type() static methods:
 
+#include "batch.h"
+#include "blob.h"
+#include "blobop.h"
+#include "column.h"
+#include "config.h"
 #include "connection.h"
 #include "connectionevent.h"
+#include "dataaccesswrapper.h"
+#include "datacomparator.h"
 #include "datahandler.h"
 #include "datamodel.h"
 #include "datamodelarray.h"
 #include "datamodelimport.h"
 #include "datamodeliter.h"
 #include "dataproxy.h"
-#include "handlerstring.h"
-#include "handlerboolean.h"
-#include "handlertime.h"
-#include "handlernumerical.h"
+#include "dataselect.h"
 #include "handlerbin.h"
+#include "handlerboolean.h"
+#include "handlernumerical.h"
+#include "handlerstring.h"
+#include "handlertime.h"
 #include "handlertype.h"
-#include "serverprovider.h"
-#include "serveroperation.h"
-#include "transactionstatus.h"
-#include "set.h"
-#include "row.h"
-#include "column.h"
 #include "holder.h"
-#include "statement.h"
-#include "sqlparser.h"
-#include "batch.h"
 #include "metastore.h"
 #include "metastruct.h"
-#include "config.h"
-#include "blobop.h"
-#include "blob.h"
 #include "quarklist.h"
-#include "datacomparator.h"
-#include "dataaccesswrapper.h"
-#include "dataselect.h"
+#include "row.h"
+#include "serveroperation.h"
+#include "serverprovider.h"
+#include "set.h"
+#include "sqlparser.h"
+#include "statement.h"
+#include "transactionstatus.h"
 #include "xatransaction.h"
 
 extern "C"
@@ -88,6 +88,8 @@ GType gda_xa_transaction_get_type(void);
 GQuark gda_connection_error_quark(void);
 GQuark gda_data_model_iter_error_quark(void);
 GQuark gda_holder_error_quark(void);
+GQuark gda_meta_store_error_quark(void);
+GQuark gda_meta_struct_error_quark(void);
 GQuark gda_server_provider_error_quark(void);
 GQuark gda_sql_parser_error_quark(void);
 GQuark gda_statement_error_quark(void);
@@ -135,6 +137,8 @@ void wrap_init()
   Glib::Error::register_domain(gda_connection_error_quark(), &Gnome::Gda::ConnectionError::throw_func);
   Glib::Error::register_domain(gda_data_model_iter_error_quark(), &Gnome::Gda::DataModelIterError::throw_func);
   Glib::Error::register_domain(gda_holder_error_quark(), &Gnome::Gda::HolderError::throw_func);
+  Glib::Error::register_domain(gda_meta_store_error_quark(), &Gnome::Gda::MetaStoreError::throw_func);
+  Glib::Error::register_domain(gda_meta_struct_error_quark(), &Gnome::Gda::MetaStructError::throw_func);
   Glib::Error::register_domain(gda_server_provider_error_quark(), &Gnome::Gda::ServerProviderError::throw_func);
   Glib::Error::register_domain(gda_sql_parser_error_quark(), &Gnome::Gda::SqlParserError::throw_func);
   Glib::Error::register_domain(gda_statement_error_quark(), &Gnome::Gda::StatementError::throw_func);
